import { Injectable, Inject } from '@angular/core';
import { Http, RequestOptions, Headers } from '@angular/http';
import 'rxjs/add/operator/map';
var AngularPrestService = /** @class */ (function () {
    function AngularPrestService(http, config) {
        this.http = http;
        this.config = config;
        if (this.config.baseUrl.substr(-1) !== '/') {
            this.config.baseUrl += '/';
        }
    }
    AngularPrestService.prototype.getToken = function () {
        var data = JSON.parse(localStorage.getItem(this.config.localStorageData) || '{}');
        return data[this.config.tokenPath];
    };
    AngularPrestService.prototype.getRequestOptions = function (params) {
        var options = {
            headers: new Headers({ 'Content-Type': 'application/json' }),
            params: params
        };
        var token = this.getToken();
        if (token) {
            options.headers.set('Authorization', "Bearer " + token);
        }
        return new RequestOptions(options);
    };
    AngularPrestService.prototype.getUrl = function (table) {
        return "" + this.config.baseUrl + table;
    };
    AngularPrestService.prototype.mapHandler = function (res, def) {
        if (def === void 0) { def = []; }
        return (res.ok && res.text()) ? res.json() : def;
    };
    AngularPrestService.prototype.get = function (table, params) {
        var _this = this;
        return this.http.get(this.getUrl(table), this.getRequestOptions(params))
            .map(function (response) { return _this.mapHandler(response)[0] || {}; });
    };
    AngularPrestService.prototype.list = function (table, params) {
        var _this = this;
        return this.http.get(this.getUrl(table), this.getRequestOptions(params))
            .map(function (response) { return _this.mapHandler(response); });
    };
    AngularPrestService.prototype.update = function (table, params, data) {
        var _this = this;
        return this.http.patch(this.getUrl(table), data, this.getRequestOptions(params))
            .map(function (response) { return _this.mapHandler(response); });
    };
    AngularPrestService.prototype.create = function (table, data, params) {
        var _this = this;
        return this.http.post(this.getUrl(table), data, this.getRequestOptions(params))
            .map(function (response) { return _this.mapHandler(response, {}); });
    };
    AngularPrestService.prototype.delete = function (table, params) {
        var _this = this;
        return this.http.delete(this.getUrl(table), this.getRequestOptions(params))
            .map(function (response) { return _this.mapHandler(response, {}); });
    };
    AngularPrestService.prototype.customQuery = function (type, url, data) {
        var _this = this;
        var result;
        switch (type.toLowerCase()) {
            case ('get'):
                result = this.http.get(url, this.getRequestOptions())
                    .map(function (response) { return _this.mapHandler(response); });
                break;
            case ('put' || 'patch'):
                result = this.http.patch(url, data, this.getRequestOptions())
                    .map(function (response) { return _this.mapHandler(response, {}); });
                break;
            case ('post'):
                result = this.http.post(url, data, this.getRequestOptions())
                    .map(function (response) { return _this.mapHandler(response, {}); });
                break;
            case ('delete'):
                result = this.http.get(url, this.getRequestOptions())
                    .map(function (response) { return _this.mapHandler(response)[0] || {}; });
                break;
        }
        return result;
    };
    AngularPrestService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    AngularPrestService.ctorParameters = function () { return [
        { type: Http, },
        { type: undefined, decorators: [{ type: Inject, args: ['config',] },] },
    ]; };
    return AngularPrestService;
}());
export { AngularPrestService };
//# sourceMappingURL=angular-prest.service.js.map